@@ -1,5 +1,5 @@
-from .record import SchemaKeepingRecordMixin, SchemaEnforcingRecord
+from .record import SchemaKeepingRecordMixin, SchemaEnforcingRecord, FilesKeepingRecordMixin
 from .marshmallow import MarshmallowValidatedRecordMixin, MarshmallowValidatedRecord
 from .signals import *
-from .loaders import json_loader
+from .loaders import json_loader, json_files_loader
 from .serializers import JSONSerializer, json_search, json_response
